from .brent import minimize as minimize_scalar
from .brent import maximize as maximize_scalar

from .bfgs import minimize
from .bfgs import maximize
